@@ -4,7 +4,7 @@ r"""*Module for* ``sphobjinv`` *CLI* |Inventory| *loading*.
 Sphinx |objects.inv| files.
 
 **Author**
-    Brian Skinn (bskinn@alum.mit.edu)
+    Brian Skinn (brian.skinn@gmail.com)
 
 **File Created**
     17 Nov 2020
@@ -16,10 +16,14 @@ Sphinx |objects.inv| files.
     https://github.com/bskinn/sphobjinv
 
 **Documentation**
-    https://sphobjinv.readthedocs.io/en/latest
+    https://sphobjinv.readthedocs.io/en/stable
 
 **License**
-    The MIT License; see |license_txt|_ for full license terms
+    Code: `MIT License`_
+
+    Docs & Docstrings: |CC BY 4.0|_
+
+    See |license_txt|_ for full license terms.
 
 **Members**
 
@@ -35,7 +39,7 @@ from jsonschema.exceptions import ValidationError
 from sphobjinv import Inventory, readjson, urlwalk, VersionError
 from sphobjinv.cli.parser import PrsConst
 from sphobjinv.cli.paths import resolve_inpath
-from sphobjinv.cli.ui import err_format, log_print
+from sphobjinv.cli.ui import err_format, print_stderr
 
 
 def import_infile(in_path):
@@ -107,14 +111,14 @@ def inv_local(params):
     try:
         in_path = resolve_inpath(params[PrsConst.INFILE])
     except Exception as e:
-        log_print("\nError while parsing input file path:", params)
-        log_print(err_format(e), params)
+        print_stderr("\nError while parsing input file path:", params)
+        print_stderr(err_format(e), params)
         sys.exit(1)
 
     # Attempt import
     inv = import_infile(in_path)
     if inv is None:
-        log_print("\nError: Unrecognized file format", params)
+        print_stderr("\nError: Unrecognized file format", params)
         sys.exit(1)
 
     return inv, in_path
@@ -156,41 +160,54 @@ def inv_url(params):
     """
     in_file = params[PrsConst.INFILE]
 
+    def attempt_inv_load(url, params):
+        """Attempt the Inventory load and report outcome."""
+        inv = None
+
+        try:
+            inv = Inventory(url=url)
+        except HTTPError as e:
+            print_stderr(f"  ... HTTP error: {e.code} {e.reason}.", params)
+        except URLError:  # pragma: no cover
+            print_stderr("  ... error attempting to retrieve URL.", params)
+        except VersionError:
+            print_stderr("  ... no recognized inventory.", params)
+        except ValueError:
+            print_stderr(
+                (
+                    "  ... file found but inventory could not be loaded. "
+                    "(Did you forget https:// ?)"
+                ),
+                params,
+            )
+        else:
+            print_stderr("  ... inventory found.", params)
+
+        return inv
+
     # Disallow --url mode on local files
     if in_file.startswith("file:/"):
-        log_print("\nError: URL mode on local file is invalid", params)
+        print_stderr("\nError: URL mode on local file is invalid", params)
         sys.exit(1)
 
-    # Need to initialize the inventory variable
-    inv = None
+    print_stderr(f"Attempting {in_file} ...", params)
+    inv = attempt_inv_load(in_file, params)
 
-    # Try URL as provided
-    try:
-        inv = Inventory(url=in_file)
-    except (HTTPError, ValueError, VersionError, URLError):
-        log_print("No inventory at provided URL.", params)
-    else:
-        log_print("Remote inventory found.", params)
+    if inv:
         url = in_file
-
-    # Keep searching if inv not found yet
-    if not inv:
+    else:
         for url in urlwalk(in_file):
-            log_print(f'Attempting "{url}" ...', params)
-            try:
-                inv = Inventory(url=url)
-            except (ValueError, HTTPError):
-                pass
-            else:
-                log_print("Remote inventory found.", params)
+            print_stderr(f'Attempting "{url}" ...', params)
+            inv = attempt_inv_load(url, params)
+            if inv:
                 break
 
     # Cosmetic line break
-    log_print(" ", params)
+    print_stderr(" ", params)
 
     # Success or no?
     if not inv:
-        log_print("No inventory found!", params)
+        print_stderr("No inventory found!", params)
         sys.exit(1)
 
     params.update({PrsConst.FOUND_URL: url})
@@ -237,5 +254,5 @@ def inv_stdin(params):
     except (AttributeError, UnicodeEncodeError, TypeError):
         pass
 
-    log_print("Invalid plaintext or JSON inventory format.", params)
+    print_stderr("Invalid plaintext or JSON inventory format.", params)
     sys.exit(1)
